==> estateplat-common-1.2.4-20200120.024723-257-sources.jar: cn/gtmap/estateplat/model/information/core/XxYsxz.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2019-12-17
 * @description 预审与选址意见书模型
 */
@Table(name = "xx_ysxz")
public class XxYsxz extends XxMxParent implements InsertVo, XxMxVo {
    @Id
    private String ywid;//主键
    @Column
    private String proid;//项目表主键
    @Column
    private String xmmc;//项目名称
    @Column
    private String xmdm;//项目代码
    @Column
    private String jsdwmc;//建设单位名称
    @Column
    private String xmjsyj;//项目建设依据
    @Column
    private String xmnxwz;//项目拟选位置
    @Column
    private Double nydmj;//拟用地面积（含各地类明细）
    @Column
    private String jsgm;//拟建设规模
    @Column
    private String nydqdfs;//拟用地取得方式
    @Column
    private String bz; //备注
    @Column
    private String xxgxqk;//信息共享情况

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXmdm() {
        return xmdm;
    }

    public void setXmdm(String xmdm) {
        this.xmdm = xmdm;
    }

    public String getJsdwmc() {
        return jsdwmc;
    }

    public void setJsdwmc(String jsdwmc) {
        this.jsdwmc = jsdwmc;
    }

    public String getXmjsyj() {
        return xmjsyj;
    }

    public void setXmjsyj(String xmjsyj) {
        this.xmjsyj = xmjsyj;
    }

    public String getXmnxwz() {
        return xmnxwz;
    }

    public void setXmnxwz(String xmnxwz) {
        this.xmnxwz = xmnxwz;
    }

    public Double getNydmj() {
        return nydmj;
    }

    public void setNydmj(Double nydmj) {
        this.nydmj = nydmj;
    }

    public String getJsgm() {
        return jsgm;
    }

    public void setJsgm(String jsgm) {
        this.jsgm = jsgm;
    }

    public String getNydqdfs() {
        return nydqdfs;
    }

    public void setNydqdfs(String nydqdfs) {
        this.nydqdfs = nydqdfs;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getXxgxqk() {
        return xxgxqk;
    }

    public void setXxgxqk(String xxgxqk) {
        this.xxgxqk = xxgxqk;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }


    @Override
    public void setDwmc(String dwmc) {
        super.dwmc = "XXXX";
    }

    @Override
    public void setDwbm(String dwbm) {
        super.dwbm = "XXXX";
    }

    @Override
    public void setMxlx(String mxlx) {
        super.mxlx = "ysxz";
    }
}

==> estateplat-common-1.2.4-20210525.090946-776-sources.jar: cn/gtmap/estateplat/model/information/core/XxYsxz.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2019-12-17
 * @description 预审与选址意见书模型
 */
@Table(name = "xx_ysxz")
public class XxYsxz extends XxMxParent implements InsertVo, XxMxVo {
    @Id
    private String ywid;//主键
    @Column
    private String proid;//项目表主键
    @Column
    private String xmmc;//项目名称
    @Column
    private String xmdm;//项目代码
    @Column
    private String jsdwmc;//建设单位名称
    @Column
    private String xmjsyj;//项目建设依据
    @Column
    private String xmnxwz;//项目拟选位置
    @Column
    private Double nydmj;//拟用地面积（含各地类明细）
    @Column
    private String jsgm;//拟建设规模
    @Column
    private String nydqdfs;//拟用地取得方式
    @Column
    private String bz; //备注
    @Column
    private String xxgxqk;//信息共享情况
    @Column
    private String tjzt;//提交状态

    public String getTjzt() {
        return tjzt;
    }

    public void setTjzt(String tjzt) {
        this.tjzt = tjzt;
    }

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXmdm() {
        return xmdm;
    }

    public void setXmdm(String xmdm) {
        this.xmdm = xmdm;
    }

    public String getJsdwmc() {
        return jsdwmc;
    }

    public void setJsdwmc(String jsdwmc) {
        this.jsdwmc = jsdwmc;
    }

    public String getXmjsyj() {
        return xmjsyj;
    }

    public void setXmjsyj(String xmjsyj) {
        this.xmjsyj = xmjsyj;
    }

    public String getXmnxwz() {
        return xmnxwz;
    }

    public void setXmnxwz(String xmnxwz) {
        this.xmnxwz = xmnxwz;
    }

    public Double getNydmj() {
        return nydmj;
    }

    public void setNydmj(Double nydmj) {
        this.nydmj = nydmj;
    }

    public String getJsgm() {
        return jsgm;
    }

    public void setJsgm(String jsgm) {
        this.jsgm = jsgm;
    }

    public String getNydqdfs() {
        return nydqdfs;
    }

    public void setNydqdfs(String nydqdfs) {
        this.nydqdfs = nydqdfs;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getXxgxqk() {
        return xxgxqk;
    }

    public void setXxgxqk(String xxgxqk) {
        this.xxgxqk = xxgxqk;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }


    @Override
    public void setDwmc(String dwmc) {
        super.dwmc = "XXXX";
    }

    @Override
    public void setDwbm(String dwbm) {
        super.dwbm = "XXXX";
    }

    @Override
    public void setMxlx(String mxlx) {
        super.mxlx = "ysxz";
    }
}
